#[repr(u32)]pub enum RelocatableHeaderTagPreference {
None = 0,
Low = 1,
High = 2,
}Expand description
Specifies the bootloader’s preferred placement for a relocatable image.
Variants
None = 0
Let the bootloader choose the image location.
Low = 1
Load the image at the lowest possible address that is not below
min_addr.
High = 2
Load the image at the highest possible address that does not end above
max_addr.