Struct multiboot2_header::Multiboot2BasicHeader
source · [−]#[repr(C)]pub struct Multiboot2BasicHeader { /* private fields */ }Expand description
Use this only if you know what you do. You probably want to use
Multiboot2Header instead.
The “basic” Multiboot2 header. This means only the properties, that are known during compile time. All other information are derived during runtime from the size property.
Implementations
sourceimpl Multiboot2BasicHeader
impl Multiboot2BasicHeader
sourcepub const fn verify_checksum(&self) -> bool
pub const fn verify_checksum(&self) -> bool
Verifies that a Multiboot2 header is valid.
sourcepub const fn calc_checksum(magic: u32, arch: HeaderTagISA, length: u32) -> u32
pub const fn calc_checksum(magic: u32, arch: HeaderTagISA, length: u32) -> u32
Calculates the checksum as described in the spec.
sourcepub const fn header_magic(&self) -> u32
pub const fn header_magic(&self) -> u32
Returns
pub const fn arch(&self) -> HeaderTagISA
pub const fn length(&self) -> u32
pub const fn checksum(&self) -> u32
sourcepub fn tag_iter(&self) -> Multiboot2HeaderTagIterⓘNotable traits for Multiboot2HeaderTagIterimpl Iterator for Multiboot2HeaderTagIter type Item = *const HeaderTag;
pub fn tag_iter(&self) -> Multiboot2HeaderTagIterⓘNotable traits for Multiboot2HeaderTagIterimpl Iterator for Multiboot2HeaderTagIter type Item = *const HeaderTag;